import Customer;
import OfficeSupply;
import OrderUnit;
import PriceBuilder;
import TaxBuilder;
import ValueAddedTax;
import ConsumptionTax;
import java.util.Vector;
import java.util.Random;
import java.lang.Math;

public class OfficeSupplyProvider
{
	//these should be imported via database
	protected Vector customers;
	protected Vector officeSupplies;
	
	//variables needed for testing
	protected Customer actualCustomer;
	protected OfficeSupply actualOfficeSupply;
	protected int actualQuantity;
	protected PriceBuilder actualPriceBuilder;
	
	public OfficeSupplyProvider()
	{
		//init customers and officeSupplies
		initCustomers( "Customers.dbs" );
		initOfficeSupplies( "OfficeSupplies.dbs" );
	}
	
	public OrderUnit createOrderUnit( int iPricingScheme )
	{		
		//create a randomized order unit
		Random fxRandomizer = new Random();
		int iNumber;
		
		
		
		////////////////////////////////////////////
		//set data
		iNumber = java.lang.Math.abs( fxRandomizer.nextInt() );
		actualCustomer = (Customer) customers.elementAt( iNumber % customers.size() );
		
		iNumber = java.lang.Math.abs(fxRandomizer.nextInt());
		actualOfficeSupply = (OfficeSupply) officeSupplies.elementAt( iNumber % officeSupplies.size() );
		
		iNumber = java.lang.Math.abs(fxRandomizer.nextInt());
		actualQuantity = (iNumber % 15) + 1;
		
		if ( iPricingScheme == 0 )
			actualPriceBuilder = new RegularPrice( actualOfficeSupply, "DM" );
		else if ( iPricingScheme == 1 )
		{
			//negotiate with customer
			actualCustomer.negotiate( actualOfficeSupply );
			actualPriceBuilder = new NegotiatedPrice( actualCustomer, "DM" );
		}
		////////////////////////////////////////////
		
		
		
		//create OrderUnit
		OrderUnit fxOrderUnit = new OrderUnit(	actualCustomer,
												actualOfficeSupply,
												actualQuantity,
												actualPriceBuilder );
		
		return fxOrderUnit;			
	}
	
	private void initCustomers( String szFileName )
	{
		//in future versions import data from File
				
		customers = new Vector();
		
		//create customers
		Customer fxCustomer;
		String szName[] = { "Anke", "Bernd", "Carsten", "Detlef", "Eva" };
		
		for (int iID=0; iID<szName.length; iID++)
		{
			fxCustomer = new Customer( iID, szName[iID] );
			
			customers.addElement( fxCustomer );	
		}
	}
	
	private void initOfficeSupplies( String szFileName )
	{
		//in future versions import data from File
				
		officeSupplies = new Vector();
		
		//create TaxBuilder
		TaxBuilder taxBuilder[] = new TaxBuilder [2];
		taxBuilder[0] = new ValueAddedTax( 0.16f );
		taxBuilder[1] = new ConsumptionTax( 0.12f );
		
		//create OfficeSupplies
		OfficeSupply fxOfficeSupply;
		String szName[] =
		{
			"Schreibtisch",
			"StehLampe",
			"Drehstuhl",
			"RollContainer",
			"Kleiderstnder"
		};
		
		float fBasePrice[] = 
		{
			799.90f,
			649.50f,
			399.90f,
			837.50f,
			245.60f
		};
		
		float fMaxDiscount[] =
		{
			80.0f,
			65.0f,
			40.0f,
			84.0f,
			25.0f
		};
		
		for (int iID=0; iID<szName.length; iID++)
		{
			fxOfficeSupply = new OfficeSupply( iID, szName[iID], fBasePrice[iID], fMaxDiscount[iID], taxBuilder );
			
			officeSupplies.addElement( fxOfficeSupply );
		}
	}
}