import Customer;
import OfficeSupply;
import PriceBuilder;

public class OrderUnit
{
	protected Customer customer;
	protected OfficeSupply officeSupply;
	protected int iQuantity;
	protected PriceBuilder priceBuilder;
		
	//Constructor
	public OrderUnit( Customer newCustomer, OfficeSupply newOfficeSupply, int iNewQuantity, PriceBuilder newPriceBuilder )
	{
		this.customer = newCustomer;
		this.officeSupply = newOfficeSupply;
		this.iQuantity = iNewQuantity;
		this.priceBuilder = newPriceBuilder;
	}
	
	//returns price of one Unit
	public float getUnitPrice()
	{		
		float fUnitPrice = this.priceBuilder.getUnitPrice( this.iQuantity );
		float fExtraCosts = this.officeSupply.getExtraCosts( fUnitPrice );
				
		return fUnitPrice + fExtraCosts;
	}
	
	//returns price of all Units
	public float getTotalPrice()
	{
		return this.getUnitPrice() * this.iQuantity;
	}
	
		
	public OfficeSupply getOfficeSupply()
	{
		return this.officeSupply;
	}
	
	public Customer getCustomer()
	{
		return this.customer;
	}
	
	public void setPriceBuilder( PriceBuilder newPriceBuilder )
	{
		this.priceBuilder = newPriceBuilder;
	}
	
	public PriceBuilder getPriceBuilder()
	{
		return this.priceBuilder;
	}
	
	public int getQuantity()
	{
		return this.iQuantity;
	}
	
	public void print()
	{
		TaxBuilder tempTaxBuilder [] = this.getOfficeSupply().getTaxes();
		String szTaxDescription = new String();
		
		for (int i=0; i<tempTaxBuilder.length; i++)
			szTaxDescription += tempTaxBuilder[i].getTaxDescription() + " ";
			
		System.out.println( "" );
		System.out.println( " ----------------" );
		System.out.println( "| Order Info: " );
		System.out.println( " -------------" );
		System.out.println( "| Customer " + this.getCustomer().getName() + " (ID " + this.getCustomer().getID() + ")" );
		System.out.println( "|   orders " + this.getQuantity() + " " + this.getOfficeSupply().getName() );
		System.out.println( "|" );
		System.out.println( "| price per unit is: " + this.getUnitPrice() + " " + this.getPriceBuilder().getCurrency() );
		System.out.println( "|                        " + this.getPriceBuilder().getBasePrice() + " (base Price)" );
		System.out.println( "|                       -" + this.getPriceBuilder().getDiscount( this.getQuantity() ) + " (discount)" );
		System.out.println( "|                           =" + this.getPriceBuilder().getUnitPrice(this.getQuantity()) + " " + this.getPriceBuilder().getCurrency() + " (unit Price)" );
		System.out.println( "|" );
		System.out.println( "|                       +" + this.getOfficeSupply().getExtraCosts(this.getPriceBuilder().getUnitPrice(this.getQuantity())) + " " + this.getPriceBuilder().getCurrency() + " (extra Costs: " + szTaxDescription + ")" );
		System.out.println( "|" );
		System.out.println( "| total price is:    " + this.getTotalPrice() + " " + this.getPriceBuilder().getCurrency() );
		System.out.println( " ----------------" );
		System.out.println( "" );
	}
}